==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/mt.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Manage Parametri Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage gallerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Daqs Wisa Image");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Daqs Għoli Image");
define('MANAGE_GALLERY_THUMB_WIDTH', "Wisa Image Thumbnail");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Għoli Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ippreserva Thumb Aspett Proporzjon");
define('MANAGE_GALLERY_SHOW_TITLES', "Titoli Uri");
define('MANAGE_GALLERY_DISABLE_SORT', "sort Itfi");
define('MANAGE_GALLERY_DELETE_IMAGE', "Ħassar Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort Ordni");
define('MANAGE_GALLERY_PUBLISH_MSG', "Ikklikkja &quot;Aġġornament&quot; biex tippubblika <br /> immaġini uploaded tiegħek.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "L-immaġini kollha ġew daqs ieħor u settings ġew salvati.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Kien hemm żball resizing l-immaġini jew iffrankar settings.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "image tiegħek (i) ikun ġie imtella.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Kien hemm żball uploading immaġini (i) tiegħek.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Il-fajl li qed tipprova biex ittella mhijiex immaġini.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Il-fajl li qed tipprova biex ittella hija kbira wisq.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "It-titolu ġie salvat.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Inti żgur li trid tħassar immaġini");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "L-immaġni ġie mħassar.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Kien hemm żball tħassar l-immaġini.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Iffrankar parametri u resizing immaġini, jekk jogħġbok stenna ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, jekk jogħġbok stenna ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L-ordni xorta ma ġew salvati. Do inti tixtieq li tiffranka l-ordni tip?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L-ordni immaġini tip ġie salvat.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Kien hemm żball iffrankar l-xorta immaġini.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/mt.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Manage Parametri Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage gallerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Daqs Wisa Image");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Daqs Għoli Image");
define('MANAGE_GALLERY_THUMB_WIDTH', "Wisa Image Thumbnail");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Għoli Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ippreserva Thumb Aspett Proporzjon");
define('MANAGE_GALLERY_SHOW_TITLES', "Titoli Uri");
define('MANAGE_GALLERY_DISABLE_SORT', "sort Itfi");
define('MANAGE_GALLERY_DELETE_IMAGE', "Ħassar Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort Ordni");
define('MANAGE_GALLERY_PUBLISH_MSG', "Ikklikkja &quot;Aġġornament&quot; biex tippubblika <br /> immaġini uploaded tiegħek.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "L-immaġini kollha ġew daqs ieħor u settings ġew salvati.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Kien hemm żball resizing l-immaġini jew iffrankar settings.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "image tiegħek (i) ikun ġie imtella.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Kien hemm żball uploading immaġini (i) tiegħek.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Il-fajl li qed tipprova biex ittella mhijiex immaġini.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Il-fajl li qed tipprova biex ittella hija kbira wisq.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "It-titolu ġie salvat.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Inti żgur li trid tħassar immaġini");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "L-immaġni ġie mħassar.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Kien hemm żball tħassar l-immaġini.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Iffrankar parametri u resizing immaġini, jekk jogħġbok stenna ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, jekk jogħġbok stenna ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L-ordni xorta ma ġew salvati. Do inti tixtieq li tiffranka l-ordni tip?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L-ordni immaġini tip ġie salvat.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Kien hemm żball iffrankar l-xorta immaġini.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Il-fajl li qed tipprova ttella &#39;huwa ikbar mill-issettjar tal-PHP&#39; upload_max_filesize &#39;jew&#39; post_max_size &#39;. Ikkuntattja lill-amministratur tas-sistema tiegħek biex iżżid dawn il-limiti.");
?>
